==> sdd.debin-jar-0.2.21.jar: ar/com/sdd/debin/io/EliminarDebinResponse.java <==
package ar.com.sdd.debin.io;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import javax.json.bind.annotation.JsonbNillable;

@JsonIgnoreProperties(ignoreUnknown=true)
@JsonbNillable
public class EliminarDebinResponse {

    private String descripcion;
    /**
     * 00: Ok
     * 87: El DEBIN se encuentra en un estado que no permite su eliminación o no existe
     * 99: Error de sistema
     */
    private String codigo;

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        this.descripcion = descripcion;
    }

    public String getCodigo() {
        return codigo;
    }

    public void setCodigo(String codigo) {
        this.codigo = codigo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        EliminarDebinResponse that = (EliminarDebinResponse) o;

        if (descripcion != null ? !descripcion.equals(that.descripcion) : that.descripcion != null) return false;
        return codigo != null ? codigo.equals(that.codigo) : that.codigo == null;
    }

    @Override
    public int hashCode() {
        int result = descripcion != null ? descripcion.hashCode() : 0;
        result = 31 * result + (codigo != null ? codigo.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "EliminarDebinResponse [" +
                "descripcion=" + descripcion +
                ", codigo=" + codigo +
                ']';
    }
}

==> sdd.debin-jar-0.4.3.jar: ar/com/sdd/debin/io/EliminarDebinResponse.java <==
package ar.com.sdd.debin.io;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.*;

@JsonIgnoreProperties(ignoreUnknown=true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class EliminarDebinResponse {

    private String descripcion;
    /**
     * 00: Ok
     * 87: El DEBIN se encuentra en un estado que no permite su eliminación o no existe
     * 99: Error de sistema
     */
    private String codigo;

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        this.descripcion = descripcion;
    }

    public String getCodigo() {
        return codigo;
    }

    public void setCodigo(String codigo) {
        this.codigo = codigo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        EliminarDebinResponse that = (EliminarDebinResponse) o;

        if (descripcion != null ? !descripcion.equals(that.descripcion) : that.descripcion != null) return false;
        return codigo != null ? codigo.equals(that.codigo) : that.codigo == null;
    }

    @Override
    public int hashCode() {
        int result = descripcion != null ? descripcion.hashCode() : 0;
        result = 31 * result + (codigo != null ? codigo.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "EliminarDebinResponse [" +
                "descripcion=" + descripcion +
                ", codigo=" + codigo +
                ']';
    }
}
